# Alvin API Client

Alvin API Client is a sdk package developed at Alvin. This is a dependency package for Alvin CLI and is installed during installation of the 
CLI package. 

Find the 

- Alvin CLI [here](https://pypi.org/project/alvin-cli)

- Alvin [docs](https://docs.alvin.ai)

- Request Invite [here](https://www.alvin.ai)